Index: include/gpu/GrTBackendEffectFactory.h |
diff --git a/include/gpu/GrTBackendEffectFactory.h b/include/gpu/GrTBackendEffectFactory.h |
index a45aeacb72abee775e30035f1196ead8c3ad52a0..450eb68ee563e67ef5b2b2a13adca11791ed8994 100644 |
--- a/include/gpu/GrTBackendEffectFactory.h |
+++ b/include/gpu/GrTBackendEffectFactory.h |
@@ -9,6 +9,7 @@ |
#define GrTBackendEffectFactory_DEFINED |
#include "GrBackendEffectFactory.h" |
+#include "GrDrawEffect.h" |
#include "gl/GrGLProgramEffects.h" |
/** |
@@ -26,7 +27,7 @@ |
* 1. The GrGLEffect used by GrEffect subclass MyEffect must be named or typedef'ed to |
* MyEffect::GLEffect. |
* 2. MyEffect::GLEffect must have a static function: |
* EffectKey GenKey(const GrEffect, const GrGLCaps&) |
* which generates a key that maps 1 to 1 with code variations emitted by |
* MyEffect::GLEffect::emitCode(). |
* 3. MyEffect must have a static function: |
@@ -45,17 +46,17 @@ |
/** Implemented using GLEffect::GenKey as described in this class's comment. */ |
- virtual void getGLEffectKey(const GrEffect& effect, |
+ virtual void getGLEffectKey(const GrDrawEffect& drawEffect, |
const GrGLCaps& caps, |
GrEffectKeyBuilder* b) const SK_OVERRIDE { |
- GLEffect::GenKey(effect, caps, b); |
+ GLEffect::GenKey(drawEffect, caps, b); |
} |
/** Returns a new instance of the appropriate *GL* implementation class |
for the given GrEffect; caller is responsible for deleting |
the object. */ |
- virtual GrGLEffect* createGLInstance(const GrEffect& effect) const SK_OVERRIDE { |
- return SkNEW_ARGS(GLEffect, (*this, effect)); |
+ virtual GrGLEffect* createGLInstance(const GrDrawEffect& drawEffect) const SK_OVERRIDE { |
+ return SkNEW_ARGS(GLEffect, (*this, drawEffect)); |
} |
/** This class is a singleton. This function returns the single instance. */ |
@@ -26,7 +27,7 @@ |
* MyEffect::GLEffect. |
* 2. MyEffect::GLEffect must have a static function: |
- * EffectKey GenKey(const GrEffect, const GrGLCaps&) |
+ * EffectKey GenKey(const GrDrawEffect, const GrGLCaps&) |
* which generates a key that maps 1 to 1 with code variations emitted by |
* MyEffect::GLEffect::emitCode(). |